==> megasync-oldherl-debug-5.4.1.0-3-x86_64.pkg.tar.zst: usr/src/debug/megasync-oldherl/MEGAsync/src/MEGASync/gui/SyncExclusions/AddExclusionRule.cpp <==
#include "AddExclusionRule.h"
#include "syncs/control/MegaIgnoreManager.h"
#include "gui/SyncExclusions/ExclusionRulesModel.h"

AddExclusionRule::AddExclusionRule(QObject *parent, const QStringList &folders)
    : QMLComponent{parent}
    , mFolders(folders)
{
}

QUrl AddExclusionRule::getQmlUrl()
{
    return QUrl(QString::fromUtf8("qrc:/sync_exclusions/AddRuleDialog.qml"));
}

QString AddExclusionRule::contextName()
{
    return QString::fromUtf8("addRuleDialogAccess");
}

void AddExclusionRule::appendRuleToFolders(int targetType, int wildCard, QString ruleValue)
{
    if(ruleValue.trimmed().isEmpty())
    {
        return;
    }

    auto splitted = ruleValue.split(QString::fromUtf8(","));
    for (const auto& folder : mFolders)
    {
        MegaIgnoreManager megaIgnoreLoader(folder, true);
        for (auto value : splitted)
        {
            value = value.trimmed();
            if (value.isEmpty())
            {
                continue;
            }

            if (targetType == ExclusionRulesModel::TargetType::EXTENSION)
            {
                megaIgnoreLoader.addExtensionRule(MegaIgnoreNameRule::Class::EXCLUDE, value);
                continue;
            }

            if((targetType == ExclusionRulesModel::TargetType::FILE
                    || targetType == ExclusionRulesModel::TargetType::FOLDER)
                && wildCard == MegaIgnoreNameRule::WildCardType::EQUAL)
            {
                value = getRelative(folder, value);
            }

            megaIgnoreLoader.addNameRule(MegaIgnoreNameRule::Class::EXCLUDE,
                                         value,
                                         targetType == ExclusionRulesModel::TargetType::FILE
                                             ? (MegaIgnoreNameRule::Target::f)
                                             : (MegaIgnoreNameRule::Target::d),
                                         static_cast<MegaIgnoreNameRule::WildCardType>(wildCard));
        }
        megaIgnoreLoader.applyChanges();
    }
}

QString AddExclusionRule::getRelative(const QString& path, const QString& fullPath)
{
    auto folder = QDir::toNativeSeparators(QDir(path).canonicalPath());
    if(!folder.isNull() && !folder.isEmpty())
    {
        QString relativePath = QDir(folder).relativeFilePath(fullPath);
        return relativePath;
    }
    return path;
}

==> megasync-oldherl-debug-6.0.0.3-4-x86_64.pkg.tar.zst: usr/src/debug/megasync-oldherl/MEGAsync/src/MEGASync/gui/SyncExclusions/AddExclusionRule.cpp <==
#include "AddExclusionRule.h"

#include "MegaIgnoreManager.h"
#include "ExclusionRulesModel.h"

AddExclusionRule::AddExclusionRule(QObject *parent, const QStringList &folders)
    : QMLComponent{parent}
    , mFolders(folders)
{
}

QUrl AddExclusionRule::getQmlUrl()
{
    return QUrl(QString::fromUtf8("qrc:/sync_exclusions/AddRuleDialog.qml"));
}

void AddExclusionRule::appendRuleToFolders(int targetType, int wildCard, QString ruleValue)
{
    if(ruleValue.trimmed().isEmpty())
    {
        return;
    }

    auto splitted = ruleValue.split(QString::fromUtf8(","));
    for (const auto& folder : mFolders)
    {
        MegaIgnoreManager megaIgnoreLoader(folder, true);
        for (auto value : splitted)
        {
            value = value.trimmed();
            if (value.isEmpty())
            {
                continue;
            }

            if (targetType == ExclusionRulesModel::TargetType::EXTENSION)
            {
                megaIgnoreLoader.addExtensionRule(MegaIgnoreNameRule::Class::EXCLUDE, value);
                continue;
            }

            if((targetType == ExclusionRulesModel::TargetType::FILE
                    || targetType == ExclusionRulesModel::TargetType::FOLDER)
                && wildCard == MegaIgnoreNameRule::WildCardType::EQUAL)
            {
                value = getRelative(folder, value);
            }
            MegaIgnoreNameRule::Target target = MegaIgnoreNameRule::Target::a;
            if (targetType == ExclusionRulesModel::TargetType::FILE)
            {
                target = MegaIgnoreNameRule::Target::f;
            }
            else if (targetType == ExclusionRulesModel::TargetType::FOLDER)
            {
                target = MegaIgnoreNameRule::Target::d;
            }
            megaIgnoreLoader.addNameRule(MegaIgnoreNameRule::Class::EXCLUDE,
                                         value,
                                         target,
                                         MegaIgnoreNameRule::Type::NONE,
                                         static_cast<MegaIgnoreNameRule::WildCardType>(wildCard));
        }
        megaIgnoreLoader.applyChanges();
    }
}

QString AddExclusionRule::getRelative(const QString& path, const QString& fullPath)
{
    auto folder = QDir::toNativeSeparators(QDir(path).canonicalPath());
    if(!folder.isNull() && !folder.isEmpty())
    {
        QString relativePath = QDir(folder).relativeFilePath(fullPath);
        return relativePath;
    }
    return path;
}
